aboutsummaryrefslogtreecommitdiff
path: root/gas/config/tc-alpha.c
diff options
context:
space:
mode:
authorKazu Hirata <kazu@codesourcery.com>2003-11-21 00:24:40 +0000
committerKazu Hirata <kazu@codesourcery.com>2003-11-21 00:24:40 +0000
commit2d2255b58e98053e88fd7d4e9be0c98567d8c739 (patch)
treebfe77fd6ab186a4ca015d2222aea734e48c1b0cf /gas/config/tc-alpha.c
parent2d8c1c626117b3f74ab75d0268af9136ea9c27da (diff)
downloadgdb-2d2255b58e98053e88fd7d4e9be0c98567d8c739.zip
gdb-2d2255b58e98053e88fd7d4e9be0c98567d8c739.tar.gz
gdb-2d2255b58e98053e88fd7d4e9be0c98567d8c739.tar.bz2
* config/tc-a29k.h: Fix comment typos.
* config/tc-alpha.c: Likewise. * config/tc-alpha.h: Likewise. * config/tc-arc.c: Likewise. * config/tc-arm.c: Likewise. * config/tc-arm.h: Likewise. * config/tc-cris.c: Likewise. * config/tc-d10v.c: Likewise. * config/tc-d30v.c: Likewise. * config/tc-dlx.c: Likewise. * config/tc-dlx.h: Likewise.
Diffstat (limited to 'gas/config/tc-alpha.c')
-rw-r--r--gas/config/tc-alpha.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/gas/config/tc-alpha.c b/gas/config/tc-alpha.c
index 83dbd34..f39c8a0 100644
--- a/gas/config/tc-alpha.c
+++ b/gas/config/tc-alpha.c
@@ -533,7 +533,7 @@ static const int alpha_num_reloc_op
/* Maximum # digits needed to hold the largest sequence # */
#define ALPHA_RELOC_DIGITS 25
/* Structure to hold explict sequence information. */
struct alpha_reloc_tag
{
fixS *master; /* the literal reloc */
@@ -1727,7 +1727,7 @@ alpha_adjust_relocs (abfd, sec, ptr)
if (! seginfo->fix_root)
return;
/* First rebuild the fixup chain without the expicit lituse and
gpdisp_lo16 relocs. */
prevP = &seginfo->fix_root;
for (fixp = seginfo->fix_root; fixp; fixp = next)
@@ -3014,7 +3014,7 @@ add_to_link_pool (basesym, sym, addend)
but this is what OSF/1 does.
If explicit relocations of the form !literal!<number> are allowed,
- and used, then explict_reloc with be an expression pointer.
+ and used, then explicit_reloc with be an expression pointer.
Finally, the return value is nonzero if the calling macro may emit
a LITUSE reloc if otherwise appropriate; the return value is the
@@ -3365,7 +3365,7 @@ load_expression (targreg, exp, pbasereg, poffset)
}
/* The lda macro differs from the lda instruction in that it handles
- most simple expressions, particualrly symbol address loads and
+ most simple expressions, particularly symbol address loads and
large constants. */
static void
@@ -533,7 +533,7 @@ static const int alpha_num_reloc_op
/* Maximum # digits needed to hold the largest sequence # */
#define ALPHA_RELOC_DIGITS 25
-/* Structure to hold explict sequence information. */
+/* Structure to hold explicit sequence information. */
struct alpha_reloc_tag
{
@@ -1727,7 +1727,7 @@ alpha_adjust_relocs (abfd, sec, ptr)
if (! seginfo->fix_root)
return;
- /* First rebuild the fixup chain without the expicit lituse and
+ /* First rebuild the fixup chain without the explicit lituse and
gpdisp_lo16 relocs. */
prevP = &seginfo->fix_root;